@@ -152,9 +152,9 @@ class MaxAndArgmax(COp):
         ]
         return Apply(self, inputs, outputs)
 
-    def perform(self, node, inp, outs, params):
+    def perform(self, node, inp, outs):
         x = inp[0]
-        axes = params
+        axes = self.axis
         max, max_idx = outs
         if axes is None:
             axes = tuple(range(x.ndim))
@@ -374,7 +374,7 @@ class Argmax(COp):
                 "You are trying to compile a graph with an old Argmax node.  Either reoptimize your graph or rebuild it to get the new node format."
             )
 
-    def perform(self, node, inp, outs, params):
+    def perform(self, node, inp, outs):
         (x,) = inp
         axes = self.axis
         (max_idx,) = outs
@@ -1369,6 +1369,11 @@ def tri_gamma(a):
     """second derivative of the log gamma function"""
 
 
+@scalar_elemwise
+def polygamma(n, x):
+    """Polygamma function of order n evaluated at x"""
+
+
 @scalar_elemwise
 def chi2sf(x, k):
     """chi squared survival function"""
@@ -3008,6 +3013,7 @@ __all__ = [
     "psi",
     "digamma",
     "tri_gamma",
+    "polygamma",
     "chi2sf",
     "gammainc",
     "gammaincc",
