@@ -594,6 +594,11 @@ class _tensor_py_operators:
                     ),
                 )
 
+    def __setitem__(self, key, value):
+        raise TypeError(
+            "TensorVariable does not support item assignment. Use the output of `set` or `add` instead."
+        )
+
     def take(self, indices, axis=None, mode="raise"):
         return at.subtensor.take(self, indices, axis, mode)
 
@@ -815,6 +820,37 @@ class _tensor_py_operators:
         """Return selected slices only."""
         return at.extra_ops.compress(self, a, axis=axis)
 
+    def set(self, idx, y, **kwargs):
+        """Return a copy of self with the indexed values set to y.
+
+        Equivalent to set_subtensor(self[idx], y). See docstrings for kwargs.
+
+        Examples
+        --------
+        >>> import pytensor.tensor as pt
+        >>>
+        >>> x = pt.ones((3,))
+        >>> out = x.set(1, 2)
+        >>> out.eval()  # array([1., 2., 1.])
+        """
+        return at.subtensor.set_subtensor(self[idx], y, **kwargs)
+
+    def inc(self, idx, y, **kwargs):
+        """Return a copy of self with the indexed values incremented by y.
+
+        Equivalent to inc_subtensor(self[idx], y). See docstrings for kwargs.
+
+        Examples
+        --------
+
+        >>> import pytensor.tensor as pt
+        >>>
+        >>> x = pt.ones((3,))
+        >>> out = x.inc(1, 2)
+        >>> out.eval()  # array([1., 3., 1.])
+        """
+        return at.inc_subtensor(self[idx], y, **kwargs)
+
 
 class TensorVariable(
     _tensor_py_operators, Variable[_TensorTypeType, OptionalApplyType]
